# Copyright (C) 2005-2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Minimal Test

This is a basic test to verify that mago-ng is working as expected and can
be run with various testing framework

To run it with:
* pyunit
    $ PYTHONPATH=<path to mago> python ./minimal.py
* nose
    $ PYTHONPATH=.. nosetests -v
* subunit with jUnit output format
    $ PYTHONPATH=.. python -m subunit.run helloword|subunit2junitxml
* testtools
    $ PYTHONPATH=.. python -m testtools.run minimal

Where <path to mago> is the path to the mago library if not in a standard
location e.g ..

You can code ldtp directly in there or an external module
The only mandatory element is '_launcher' (and _win_name for now)

set _setupOnce to False to launch/close the app for each test
"""

from mago import TestCase
import nose
import os
import ldtp

LBL_UNABLETOOPENDOCUMENT = 'lblUnabletoopendocument'

class TestEvince(TestCase):
    launcher = 'evince'
    window_name = 'frm0'
    datadir = os.path.join(os.path.dirname(__file__), 'data')
    testfile = None

    @classmethod
    def setUpClass(self):
        """Class setup

        Build the document list from the content of the data directory
        which will be used in the tests
        """
        self.doclist = {}
        for f in os.listdir(self.datadir):
            try:
                ext = f.split('.',1)[1]
                # Only take the first occurrence for an extension
                if not ext in self.doclist:
                    self.doclist[ext] = f
            except:
                pass

        super(TestEvince, self).setUpClass()

    def openDocument(self, extension):
        """Open the first document in datadir with the given extension

        :param extension: File extension
        """

        try:
            docname = self.doclist[extension]
        except KeyError:
            return False

        self.testfile = os.path.join(self.datadir, docname)
        return self.application.openDocument( self.testfile )

    def test_open_bmp(self):
        """Open a document of type 'PC bitmap' (.bmp)"""
        self.assertTrue(self.openDocument('bmp'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_cb7(self):
        """Open a document of type 'Comic Book 7-zip archive data' (.cb7)"""
        self.assertTrue(self.openDocument('cb7'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_cbr(self):
        """Open a document of type 'Comic Book RAR archive data, v1d' (.cbr)"""
        self.assertTrue(self.openDocument('cbr'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_cbt(self):
        """Open a document of type 'Comic Book POSIX tar archive (GNU)' (.cbt)"""
        self.assertTrue(self.openDocument('cbt'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_cbz(self):
        """Open a document of type 'Comic Book Zip archive data' (.cbz)"""
        self.assertTrue(self.openDocument('cbz'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_djvu(self):
        """Open a document of type 'DjVu multiple page document' (.djvu)"""
        self.assertTrue(self.openDocument('djvu'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_dvi(self):
        """Open a document of type 'TeX DVI file' (.dvi)"""
        self.assertTrue(self.openDocument('dvi'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_eps(self):
        """Open a document of type 'PostScript document text' (.eps)"""
        self.assertTrue(self.openDocument('eps'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_gif(self):
        """Open a document of type 'GIF image data' (.gif)"""
        self.assertTrue(self.openDocument('gif'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_jpg(self):
        """Open a document of type 'JPEG image data' (.jpg)"""
        self.assertTrue(self.openDocument('jpg'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_pdf(self):
        """Open a document of type 'PDF document' (.pdf)"""
        self.assertTrue(self.openDocument('pdf'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_pdfbz2(self):
        """Open a document of type 'PDF bzip2 compressed data' (.pdf.bz2)"""
        self.assertTrue(self.openDocument('pdf.bz2'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_pdfgz(self):
        """Open a document of type 'PDF gzip compressed data' (.pdf.gz)"""
        self.assertTrue(self.openDocument('pdf.gz'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_png(self):
        """Open a document of type 'PNG image data' (.png)"""
        self.assertTrue(self.openDocument('png'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_pnm(self):
        """Open a document of type 'Netpbm PPM "rawbits" image data' (.pnm)"""
        self.assertTrue(self.openDocument('pnm'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_ps(self):
        """Open a document of type 'PostScript document' (.ps)"""
        self.assertTrue(self.openDocument('ps'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_tif(self):
        """Open a document of type 'TIFF image data' (.tif)"""
        self.assertTrue(self.openDocument('tif'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_tiff(self):
        """Open a document of type 'TIFF image data' (.tiff)"""
        self.assertTrue(self.openDocument('tiff'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)

    def test_open_xpm(self):
        """Open a document of type 'X pixmap image text' (.xpm)"""
        self.assertTrue(self.openDocument('xpm'),
                        "Failed to open document '%s'" % self.testfile)

        self.assertTrue(not ldtp.guiexist(self.window_name,
                                          LBL_UNABLETOOPENDOCUMENT),
                        "Failed to open document '%s'" % self.testfile)





if __name__ == "__main__":
    nose.main()
