# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""LibreOffice Test

This test verifies OOo functionalities

To run it with:
$ mago-ng <path_to_this_file>

"""

from mago import TestCase
import unittest
import ldtp, ooldtp

class TestOOo(TestCase):
    """Test OOo functionalities
    """
    launcher = 'ooffice'
    window_name = 'frm*Office*'


    MNU_SPREADSHEET = 'mnuSpreadsheet'
    MNU_PRESENTATION = 'mnuPresentation'
    MNU_DRAWING = 'mnuDrawing'
    MNU_DOCUMENT = 'mnuTextDocument'
    MNU_CLOSE = 'mnuClose'
    MNU_QUIT = 'mnuQuit'
    BTN_CREATE = 'btnCreate'
    FRM_IMPRESS = 'frm*Impress'

    _appnames = {
        'writer':(MNU_DOCUMENT, 'frm*Writer'),
        'calc':(MNU_SPREADSHEET,'frm*Calc'),
        'impress':(MNU_PRESENTATION, 'dlgPresentationWizard'),
        'draw':(MNU_DRAWING, 'frm*Draw')
    }


    def __about(self):
        """Open and close the about dialog
        Return True on success
        """
        # The window manager needs time, give it time
        ldtp.wait(2)
        rc = self.application.about_open()
        self.assertTrue(rc)
        dlgAboutName = self.application.dlgAboutName
        self.assertIsNotNone(dlgAboutName,
                             "Name of the about dialog was not found")
        self.assertTrue(ldtp.guiexist(dlgAboutName))

        # Then close it
        rc = self.application.about_close('btnOK')
        self.assertTrue(rc)
        self.assertFalse(ldtp.guiexist(dlgAboutName))

        return True

    def __runApp(self, appname):
        """Launch one OOo application

        :param appname: Name of the OOo application

        The list of valid application is:
           - writer
           - calc
           - impress
           - draw
        """
        appname = appname.lower()

        if not appname in self._appnames:
            raise AssertionError("The application '%s' is not a valid OO.o application" % appname)

        self.application.context.click(self._appnames[appname][0])
        ldtp.wait(2)
        ldtp.waittillguiexist(self._appnames[appname][1])
        ldtp.wait(2)
        appobj = ooldtp.context(self._appnames[appname][1])

        ldtp.wait(2)
        if 'impress' in appname:
            appobj.click(self.BTN_CREATE)
            ldtp.waittillguiexist(self.FRM_IMPRESS)
            ldtp.wait(2)
            ldtp.click(self.FRM_IMPRESS, self.MNU_CLOSE)
        else:
            appobj.click(self.MNU_CLOSE)
        return True


    def test_01MainMenu(self):
        """ This test verifies that the main application can be launched
        """
        self.assertTrue( self.__about())

    def test_02Writer(self):
        """Launch Writer"""
        self.assertTrue( self.__runApp('writer'))

    def test_03Calc(self):
        """Launch Calc"""
        self.assertTrue( self.__runApp('calc'))

    def test_04Impress(self):
       """Launch Impress"""
       self.assertTrue( self.__runApp('impress'))

    def test_05Draw(self):
        """Launch Draw"""
        self.assertTrue( self.__runApp('draw'))

if __name__ == "__main__":
    unittest.main()
