# Copyright (C) 2005-2011 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Shotwell Tests
    - Import copy
    - Import link
    - Import F-Spot
    - Add/Remove tags
    - Filter by ratinmportg
    - Export
    - Adjust time/date metadata

This test will delete all photos stored by Shotwell
This test requires that test_shotwell.ini is configured to pass tests
All source data files get copied to a temp dir to avoid source data corruption
"""

from mago import TestCase
import unittest
import ldtp
import ooldtp
import os
import shutil
from shotwell_appmap import *

class TestShotwell(TestCase):
    """Test shotwell app"""
    launcher = 'shotwell'
    launcher_args = ['%U']
    window_name = 'frmShotwell'
    shotwell = None
    tmpdir = None

    def setUp(self):
        """Returns shotwell to a known state"""
        super(TestShotwell, self).setUp()
        self.tmpdir = self.testConfig.get('data', 'tmppath')
        self.shotwell = self.application.context
        self.shotwell.click(menu.allPhotos) #reset filter
        if self.shotwell.stateenabled(menu.selectAll):
            self.shotwell.click(menu.selectAll)  
            self.shotwell.click(menu.moveToTrash)
            ldtp.wait(1)
            self.shotwell.click(menu.emptyTrash)
            ldtp.waittillguiexist(dialog.warning)
            ldtp.click(dialog.warning, button.trashFiles)
            ldtp.wait(1)
            if ldtp.guiexist(dialog.question):
                ldtp.click(dialog.question, button.keep)       

    def __import_from_folder(self, copy=True):
        """Import image using the import from folder by copying or linking the images

        :param copy: defaults to True, set to False to link images
        """
        try:
            shutil.rmtree(self.tmpdir)
        except IOError, OSError:
            pass #continue
        # copy images foldwe to tmpdir
        shutil.copytree(os.path.join(os.path.dirname(__file__), 'images'), os.path.join(self.tmpdir, 'images'))

        # select import from folder menu item
        self.shotwell.click(menu.importFromFolder)

        # input images folder path
        ldtp.waittillguiexist(dialog.importFromFolder)
        importDialog = ooldtp.context(dialog.importFromFolder)
        importDialog.check(button.typeAFilename)
        imagesdir = os.path.join(self.tmpdir, 'images')
        importDialog.settextvalue(text.location, imagesdir)
        importDialog.click(button.ok) 
	
	    # click copy option
        ldtp.waittillguiexist(dialog.question)
        importLibraryDialog = ooldtp.context(dialog.question)
        if copy:
            importLibraryDialog.click(button.copyPhotos)
        else:
            importLibraryDialog.click(button.importInPlace)

	    # assert n photos imported message label
        ldtp.waittillguiexist(dialog.information)
        infoDialog = ooldtp.context(dialog.information)
        infoDialog.waittillguiexist(label.photosSuccessfullyImported % 2) #parameterize count
        infoDialog.click(button.ok)        
       
        #  assert files displayed
        self.shotwell.click(menu.selectAll)
        self.shotwell.waittillguiexist(label.photosDisplayed % 2)

    def test_import_from_folder_copy(self):
        """Imports images via copying from folder"""
        self.__import_from_folder() 

    def test_import_from_folder_link(self):
        """Imports images via linking from folder"""
        self.__import_from_folder(copy=False)

    def test_add_and_remove_tags(self):
        """Adds and removes tags from images"""
        self.__import_from_folder()
        self.shotwell.click(menu.selectAll)
        self.shotwell.click(menu.addTags)
        ldtp.waittillguiexist(dialog.addTags)
        ldtp.settextvalue(dialog.addTags, text.tags, 'test,123')
        ldtp.click(dialog.addTags, button.ok)
        self.assertTrue(self.shotwell.doesrowexist(table.navigationPanel, 'test'))
        self.assertTrue(self.shotwell.doesrowexist(table.navigationPanel, '123'))
       
    def test_filter_by_rating(self):
        """Applies an image rating and filters the displayed images"""
        self.__import_from_folder()
        # select all and apply rating
        self.shotwell.click(menu.setRating1)
        # filter by different rating
        self.shotwell.click(menu.filterPhotos2OrBetter) 
        # assert no photos
        self.assertFalse(self.shotwell.stateenabled(menu.selectAll))
        # filter by applited rating
        self.shotwell.click(menu.filterPhotos1OrBetter)
        # assert photos display
        self.shotwell.click(menu.selectAll)
        self.assertTrue(self.shotwell.guiexist(label.photosDisplayed % 2))

    def test_export(self):
        """Exports imagess as PNGs to another directory"""
        self.__import_from_folder()
        # select photos
        self.shotwell.click(menu.selectAll)
        # export default settings
        self.shotwell.click(menu.export)
        # use /tmp/shotwelltest 
        ldtp.waittillguiexist(dialog.exportPhotos)
        exportDialog = ooldtp.context(dialog.exportPhotos)     
        exportDialog.click(menu.png)
        exportDialog.click(button.ok)
        ldtp.waittillguiexist(dialog.exportPhotos)
        exportDialog.remap()
        exportDialog.check(button.typeAFilename)
        exportDialog.remap()
        exportDialog.settextvalue(text.location, self.tmpdir)
        exportDialog.click(button.ok) 
        # assert files exist in fs
        for i in range(1, 30): 
            # get ldtp default timeout -- int(os.getenv('GUI_TIMEOUT')):
            if os.path.exists(os.path.join(self.tmpdir, 'ubuntu01.png')):
                self.assertTrue(len(os.listdir(self.tmpdir)) == 3) # images and images/
                break
            else:
                if i >= 30:
                    self.fail("%s dir does not exist, export failed" % self.tmpdir)
                ldtp.wait(1)

    def test_import_from_fspot(self):
        """Imports images from an F-Spot .db file"""
        # import from f-spot menu
        self.shotwell.click(menu.importFromFSpot)
        # import from another db file
	ldtp.waittillguiexist(dialog.importFromFSpot)
        importFSpotDialog = ooldtp.context(dialog.importFromFSpot)
        importFSpotDialog.click(radioButton.importFSpotDbFile)
        importFSpotDialog.click(button.fSpotDbFile)
        # click select a file
        ldtp.waittillguiexist(dialog.selectAFile)
        selectFileDialog = ooldtp.context(dialog.selectAFile)
        selectFileDialog.check(button.typeAFilename)
        selectFileDialog.remap()
        # clear fspot files
        try:
            shutil.rmtree(self.tmpdir)
        except OSError, IOError:
            pass # continue if path does not exist
        # copy source file to a tmp dir
        fSpotSrcFile = os.path.join(os.path.dirname(__file__), 'fspot', 'photos.db')
        os.makedirs(os.path.join(self.tmpdir, 'fspot'))
        tmpFSpotdir = os.path.join(self.tmpdir, 'fspot')
        shutil.copy(fSpotSrcFile, tmpFSpotdir)
        selectFileDialog.settextvalue(text.location, os.path.join(tmpFSpotdir, 'photos.db'))
        ldtp.wait(2)
        selectFileDialog.click(button.open) 
        ldtp.wait(5)
        importFSpotDialog.click(button.ok)
        # import complete window - ok
        ldtp.waittillguiexist(dialog.information)
        importCompleteDialog = ooldtp.context(dialog.information)
        importCompleteDialog.waittillguiexist(label.photosSuccessfullyImported % 2) #parameterize count
        importCompleteDialog.click(button.ok)
        #  assert files displayed
        self.shotwell.click(menu.selectAll)
        self.assertTrue(self.shotwell.guiexist(label.photosDisplayed % 2))

    def test_metadata(self):
        """Changes the date metadata"""
        self.__import_from_folder() 
        # select all photos
        self.shotwell.click(menu.selectAll)
        # adjust date and time
        self.shotwell.click(menu.adjustDateTime)
        # store hour value
        ldtp.waittillguiexist(dialog.adjustDateTime)
        dateTimeDialog = ooldtp.context(dialog.adjustDateTime)
        self.assertFalse(dateTimeDialog.guiexist(label.originalDateTime))
        if dateTimeDialog.guiexist(comboSelect.meridiem % meridiem.am):
            dateTimeDialog.comboselect(comboSelect.meridiem % meridiem.am, menu.meridiem % meridiem.pm)
            currentMeridiem = merdiem.pm
        else:
            dateTimeDialog.comboselect(comboSelect.meridiem % meridiem.pm, menu.meridiem % meridiem.am)
            currentMeridiem = meridiem.am
        dateTimeDialog.check(checkbox.modifyOriginalFiles)
        dateTimeDialog.click(button.ok)

        # assert that hour values are different
        self.shotwell.click(menu.selectAll)
        self.shotwell.click(menu.adjustDateTime)
        ldtp.waittillguiexist(dialog.adjustDateTime)
        dateTimeDialog.remap()
        self.assertTrue(dateTimeDialog.guiexist('lbl*' + currentMeridiem)) 

if __name__ == "__main__":
    unittest.main()
    
