# Copyright (C) 2010 Canonical Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

"""Time Admin Test

Test the time-admin applet:
    - Compare the time-admin date with the system date
    - Change the date
    - Change the timezone

This test requires user authentication. It can be defined in a configuration
file:

; To pass the test you need to specify valid credentials in the included file:
; [auth]
; username=USERNAME
; password=PASSWORD


To run it with:
$ mago-ng <path_to_this_file>

"""

from mago import TestCase
import unittest
import ldtp
import time

class TestTimeAdmin(TestCase):
    """Test the time-admin applet
    """
    launcher = 'time-admin'
    window_name = 'dlgTimeandDateSettings'

    sbtn_hh = 'sbtn0'
    sbtn_mm = 'sbtn1'
    sbtn_ss = 'sbtn2'

    def __gettime(self):
        """Read time from the time applet and returns a list (hh:mm:ss)"""
        hh = self.application.context.gettextvalue( self.sbtn_hh )
        mm = self.application.context.gettextvalue( self.sbtn_mm )
        ss = self.application.context.gettextvalue( self.sbtn_ss )

        return map(lambda x: "%02d" % int(x), (hh, mm, ss))

    def __settime(self, hh = 0, mm = 0, ss = 0):
        """Set time using the time applet

        :param hh: Hours
        :param mm: Minutes
        :param ss: Seconds
        """
        self.application.context.settextvalue( self.sbtn_hh, "%02d" % int(hh) )
        self.application.context.settextvalue( self.sbtn_mm, "%02d" % int(mm) )
        self.application.context.settextvalue( self.sbtn_ss, "%02d" % int(ss) )
        ldtp.generatekeyevent('<tab>')

    def setUp(self):
        """setUp method. Click on btn2 to popup the auth dialog """
        super(TestTimeAdmin, self).setUp()
        ldtp.click(self.window_name, 'btn2')

    def test_01checktime(self):
        """Check that the time in the applet is the same than the local time
        returned by the system

        """
        tt = self.__gettime()

        self.assertEqual( "%s:%s" % (tt[0], tt[1]),
                         time.strftime('%H:%M', time.localtime()))

    def test_02changetime(self):
        """Change the time and compare to local time returned by the system

        This test requires a valid password
        """
        if not self.testConfig.has_option('auth', 'password'):
            raise self.failureexception,"password is mandatory. set it in the configuration file"

        time_orig = self.__gettime()

        password = self.testConfig.get('auth', 'password')
        hhmm = self.testConfig.get('data', 'time').split(':')
        rc = self.application.authenticate(password)
        self.assertTrue(rc)

        self.__settime(hhmm[0], hhmm[1]) 
        time_test = self.__gettime()


        # Check that the component is updated
        self.assertEqual( hhmm[0], time_test[0] )
        self.assertEqual( hhmm[1], time_test[1] )

        # Need to wait a few seconds in order to update system time
        ldtp.wait(5)
        # Has system been updated?
        self.assertEqual( "%s:%s" % (hhmm[0], hhmm[1]),
                         time.strftime('%H:%M', time.localtime()))

        # Restore time
        self.__settime(time_orig[0], time_orig[1], time_orig[2])


    def test_03changetimezone(self):
        """Change the timezone"""
        raise NotImplementedError

#    def test_password(self):
#        """test authentication with a valid password
#
#        this test enters a valid password and check the authenticate returned
#        true, that the dialog is not there anymore and that the calendar is
#        enabled (meaning that the authentication succeeded)
#        """
#        if not self.testconfig.has_option('auth', 'password'):
#            raise self.failureexception,"password is mandatory. set it in the configuration file"
#
#        password = self.testconfig.get('auth', 'password')
#        rc = self.application.authenticate(password)
#        self.asserttrue(rc)
#        self.assertfalse(ldtp.guiexist('dlgauthenticate'))
#        self.asserttrue(ldtp.stateenabled(self.window_name, 'caldate'))
#
#    def test_cancel(self):
#        """test the cancel action of the authentication dialog
#
#        open the authentication dialog and cancel, then check the return status
#        and that the dialog is closed
#        """
#        rc = self.application.authenticate(cancel = True)
#
#        self.assertTrue(rc)
#        self.assertFalse(ldtp.guiexist('dlgAuthenticate'))
#
#
#    def test_wrongpassword(self):
#        """Test authentication with a wrong password
#
#        The test enters a wrong password and check that authenticate returns
#        False, that the dialog is still there.
#
#        Then call authenticate again with cancel and check that the return
#        status is True and the dialog vanished
#        """
#        # Set an invalid password
#        rc = self.application.authenticate(password = "this password is invalid")
#        self.assertFalse(rc)
#        self.assertTrue(ldtp.guiexist('dlgAuthenticate'))
#
#        # Cancel the auth. dialog
#        rc = self.application.authenticate(cancel = True)
#        self.assertTrue(rc)
#        self.assertFalse(ldtp.guiexist('dlgAuthenticate'))


if __name__ == "__main__":
    unittest.main()
